/*
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
 */
accountantApp

.factory("ScheduledOperations", ["$resource", function($resource) {
    return $resource(
        "/api/scheduled_operations/:id", {
            id: "@id"
        }
    );
}])

.controller(
    "SchedulerController", [
        "$scope", "$rootScope", "$routeParams", "notificationService", "ScheduledOperations",
        function($scope, $rootScope, $routeParams, notificationService, ScheduledOperations) {
    // Operations store and selection
    $scope.operations = [];

    $scope.categories = [];

    $scope.addOperation = function() {
        if(! $scope.inserted) {
          $scope.inserted = new ScheduledOperations({});
          $scope.inserted.account_id = $routeParams.accountId;
          $scope.operations.splice(0, 0, $scope.inserted);
        }
    };

    $scope.loadOperations = function(accountId) {
      // Clean up selected entry.
      $scope.selectedOperation = null;
      $scope.savedOperation = null;

      $scope.operations = ScheduledOperations.query({
          account: $routeParams.accountId
      });
    };

    // Save operation.
    $scope.saveOperation = function($data, $index) {
      var operation;

      if($data.$save) {
        operation = $data;
      } else {
        operation = $scope.operations[$index];
        operation = angular.merge(operation, $data);
      }

      var promise = operation.$save()

      if(operation == $scope.inserted) {
        promise = promise.then(function(data) {
          $scope.inserted = false;
          return data;
        });
      }

      return promise.then(function(data) {
        notificationService.success("Operation #" + data.id + " saved.");
        return data;
      });
    };

    // Reload operation from server to cancel edition.
    $scope.cancelEditOperation = function(operation, rowform) {
      if(operation == $scope.inserted) {
        $scope.entries.splice(0, 1);
      } else {
        rowform.$cancel();
      }
    };

    // Load operations on controller initialization.
    $scope.loadOperations($routeParams.accountId);
}]);
